==> cmsmadesimple-1.8.2p0.tgz: cms/modules/nuSOAP/lang/ext/de_DE.php <==
<?php
$lang['postinstall'] = 'Das nuSOAP-Modul wurde installiert';
$lang['postuninstall'] = 'nuSOAP - Deinstallation komplett';
$lang['uninstalled'] = 'nuSOAP - nicht installiert';
$lang['friendlyname'] = 'nuSOAP-Modul';
$lang['moddescription'] = 'Ein Modul zur Durchf&uuml;hrung von SOAP-Transaktionen mit CMSms';
$lang['installed'] = 'Installiert';
$lang['upgraded'] = 'Aktualisiert';
$lang['error'] = 'Fehler';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Eigentlich nicht viel. Es ist kein Tag-Modul und hat keine Administration. Dieses Modul ist ein einfacher Wrapper f&uuml;r die nuSOAP-Klassen. Es bietet eine SOAP-Engine f&uuml;r CMSms, um Nachrichten zwischen einen SOAP-Server und einem SOAP-Client auszutauschen. Dieses Modul kann anderen Modulen erlauben, entweder als Server oder als Client zu agieren.</p>
<h3>Wie wird es eingesetzt?</h3>
<p>Gar nicht. Dieses Modul kann nicht direkt auf einer Seite verwendet werden, sondern ist vielmehr ein Werkzeug f&uuml;r andere Module. Wenn Sie Modulentwickler sind und SOAP-Module f&uuml;r CMS made simple entwickeln wollen, finden Sie auf der Webseite des nuSOAP-Projekts weitere Informationen: <a href="http://www.scottnichol.com/soap.htm">http://www.scottnichol.com/soap.htm</a></p>
<p>Ich habe lediglich <em>(um Namenskonflikte zu vermeiden)</em> die Klassenbibliothek des Clients umbenannt, das ist schon alles.</p>
<h3>Berechtigungen</h3
<p>Dieses Modul erfordert keine besonderen Berechtigungen.</p>';
$lang['changelog'] = '<ul>
<li>1.0.1 - August, 2006
<p>Erweiterung um den &quot;lazy load&quot; Mechanismus</p>
</li>
<li>1.0 - Juli 2006
<p>Obwohl das Modul bereits eine Weile existiert, ist dies die erste offizielle Version.</p>
</li>
</ul>
';
$lang['utma'] = '156861353.717462736.1147511856.1237317592.1237328557.347';
$lang['utmz'] = '156861353.1234888676.321.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p3.tgz: cms/modules/nuSOAP/lang/ext/de_DE.php <==
<?php
$lang['postinstall'] = 'Das nuSOAP-Modul wurde installiert';
$lang['postuninstall'] = 'Das nuSOAP-Modul wurde deinstalliert';
$lang['uninstalled'] = 'Das nuSOAP-Modul ist nicht installiert';
$lang['friendlyname'] = 'nuSOAP-Modul';
$lang['moddescription'] = 'Ein Modul zur Durchf&uuml;hrung von SOAP-Transaktionen mit CMSMS';
$lang['installed'] = 'Installiert';
$lang['upgraded'] = 'Aktualisiert';
$lang['error'] = 'Fehler';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Eigentlich nicht viel. Es ist kein Tag-Modul und hat keine Administration. Dieses Modul ist ein einfacher Wrapper f&uuml;r die nuSOAP-Klassen. Es bietet eine SOAP-Engine f&uuml;r CMSms, um Nachrichten zwischen einen SOAP-Server und einem SOAP-Client auszutauschen. Dieses Modul kann anderen Modulen erlauben, entweder als Server oder als Client zu agieren.</p>
<h3>Wie wird es eingesetzt?</h3>
<p>Gar nicht. Dieses Modul kann nicht direkt auf einer Seite verwendet werden, sondern ist vielmehr ein Werkzeug f&uuml;r andere Module. Wenn Sie Modulentwickler sind und SOAP-Module f&uuml;r CMS made simple entwickeln wollen, finden Sie auf der Webseite des nuSOAP-Projekts weitere Informationen: <a href="http://www.scottnichol.com/soap.htm">http://www.scottnichol.com/soap.htm</a></p>
<p>Ich habe lediglich <em>(um Namenskonflikte zu vermeiden)</em> die Klassenbibliothek des Clients umbenannt, das ist schon alles.</p>
<h3>Berechtigungen</h3
<p>Dieses Modul erfordert keine besonderen Berechtigungen.</p>';
$lang['changelog'] = '<ul>
<li>1.0.1 - August, 2006
<p>Erweiterung um den &quot;lazy load&quot; Mechanismus</p>
</li>
<li>1.0 - Juli 2006
<p>Obwohl das Modul bereits eine Weile existiert, ist dies die erste offizielle Version.</p>
</li>
</ul>
';
$lang['utma'] = '156861353.178890951.1298889837.1299177721.1299280219.6';
$lang['utmz'] = '156861353.1298889837.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
